#include <cstdio>
#include <cstdlib>
#define LINE_MAX_LENGTH 500

#define readline(s) fgets((s), LINE_MAX_LENGTH + 2, stdin)
// + 2 means 2 extra spaces for \n and \0

#define LOWERCASE(c) (c >= 'a' && c <= 'z')
#define UPPERCASE(c) (c >= 'A' && c <= 'Z')
#define ALPHA(c) (LOWERCASE(c) || UPPERCASE(c))
#define UPPERCASE_COEFFICIENT 2
#define ASTERISK_COEFFICIENT 3
using namespace std;


// Our simple structure for fractions.
// Since the average loudness of a line is a rational number,
// we will store it in this structure to achieve better
// precision than double would offer.
struct fraction {
  int numerator;
  int denominator;
};

bool operator< (fraction &a, fraction& b) {
  return a.numerator * b.denominator < b.numerator * a.denominator;
}


int main() {
  int num_testcases;                    // Number of testcases.
  char input[LINE_MAX_LENGTH + 2];      // Input string buffer.
  
  // Read the number of test cases.
  readline(input);
  num_testcases = atoi(input);

  // Process the t testcases.
  while (num_testcases--) {
    // Ignore the first blank line.
    readline(input);
    
    // Read the number of lines    
    readline(input);
    int num_lines = atoi(input);
    
    int loudest_index = 0;                     // Index of the loudest line.
    fraction loudest_value = (fraction){0, 1}; // Loudness of the loudest line.
    
    // Examine all lines.
    for (int current_line = 0; current_line < num_lines; current_line++) {
      readline(input);
      
      int word_value = 1;                 // current word loudness
      int line_value = 0;                 // total loudness of words in this line
      int word_count = 0;                 // number of words in this line
      bool in_asterisks = false;          // are we between two asterisks?
      bool seen_lowercase = false;        // have we seen lowercase letters?
          
      for (int i = 0; input[i]; i++) {
        // Asterisks.
        if (input[i] == '*') {
          in_asterisks = !in_asterisks;
        }
        
        // Beginning of a word.
        if (ALPHA(input[i]) && (i == 0 || !ALPHA(input[i - 1]))) {
          seen_lowercase = false;
          word_value = 1;
        }
        
        // Inside a word.
        if (ALPHA(input[i]) && LOWERCASE(input[i])) {
          seen_lowercase = true;
        }
              
        // End of a word.
        if (ALPHA(input[i]) && !ALPHA(input[i + 1])) {
          if (!seen_lowercase)
            word_value *= UPPERCASE_COEFFICIENT;
          if (in_asterisks)
            word_value *= ASTERISK_COEFFICIENT;
          
          line_value += word_value;
          word_count++;
        }
      }
      
      // Compute the average loudness in this line
      // and compare it to the maximum.
      fraction avg_loudness = (fraction){line_value, word_count};
      
      if (loudest_value < avg_loudness) {
        loudest_value = avg_loudness;
        loudest_index = current_line + 1;
      }
    }
    
    // Output the index of the loudest line in this test case.
    printf("%d\n", loudest_index);
  }
  
  return 0;
}
